# Robustness Evaluation and Enhancement Toolbox

The Robustness Evaluation and Enhancement Toolbox (REET) provides tools for measuring and improving the robustness of ML models. REET uses adversarial optimisation with data transforms (adversarial transforms) to generate challenging transformations of input data. This allows you to measure robustness to a transform by evaluating the degradation in performance on the transformed data compared to the input data, or improve robustness by using adversarial transforms for data augmentation during training.



## Usage
`main.ipynb` provides a tutorial for using the toolbox to evaluate a trained model and efficiently train a more robust model.


